@@ -34,18 +34,12 @@ class csv_operator:
 	
 	
 	def new_row(self,data):
-		current_row=0
-		for _,_ in self.df.iterrows():
-			current_row+=1
-		self.df.loc[current_row]=data
+		self.df.loc[data[0]]=data[1]
 		return self.df
 		
 		
 		
 	def new_col(self,data):
-		current_col=1
-		for _ in self.df:
-			current_col+=1
 		self.df[data[0]]=data[1]
 		return self.df
 		
